.. :changelog:

History
-------

0.2.4 (2024-07-04)
++++++++++++++++++

* Made optional `python-slugify` and `feedparser`
* Fixed documentation's build
* Upgrade of `django-example`
* Fixed old `OSMGeoAdmin` for Django 4.0 and newer

0.2.3 (2024-07-03)
++++++++++++++++++

* Checked `ugettext` and `gettext` for compatibility with Django 4.0 and upper
* python-slugify optional, using django slugify as fallback
* Set django.db.models.BigAutoField

0.2.2 (2021-06-01)
++++++++++++++++++

* Fixed related_name and related_query_name at AbstractOfficialArea model
* Updated python-slugify according its documentation

0.2.1 (2021-03-19)
++++++++++++++++++

* Added BaseInspireEUModel at CadastralZoning and CadastralParcel
* Typo fixed AbstractCadastralParcel.national_cadastal_reference to AbstractCadastralParcel.national_cadastral_reference

0.2.0 (2021-02-26)
++++++++++++++++++

* First release on PyPI.

0.1.0 (2021-02-07)
++++++++++++++++++

* First release on GitHub.
